
clc; clear;

%% Caclulating basics

weight_water = 2030424.18; %[N] single wire
Weight_air = 2741187.92; %[N] single wire

% Drag
F_drag = @(u) 1*0.5*1025*2*45*u.^2;

%% Reading from analysis
filename = './input/parameters';
delimiterIn = '\t';
headerlinesIn = 1;
[A, delimiterOut] = importdata(filename,delimiterIn,headerlinesIn);


parameters = A.data;

%% Define text strings 

t1 = 'Cd=';
t2 = 'Cm=';
ti = 'ti=';
force_str = 'dynres.out_Element_Force_Elem_201_End_2_Dof_1.plo';
disp_str = 'dynres.out_Nodal_Displacement_Node_105_Dof_3.plo';
vel_str = 'dynres.out_Nodal_Velocity_Node_1_Dof_3.plo';

for i = 1:length(parameters)
    t_open(i,:)= [t1 num2str(parameters(i,1)) '_' t2 num2str(parameters(i,2)) '_' ti num2str(parameters(i,3))];
    t_read1(i,:) = ['./analysis/' t_open(i,:) '/' disp_str];
    t_read2(i,:) = ['./analysis/' t_open(i,:) '/' force_str];
    t_read3(i,:) = ['./analysis/' t_open(i,:) '/' vel_str];
end


%% Read the data dynres files 

 for i = 1:length(parameters)
     data_disp = load (t_read1(i,:));
     data_force = load (t_read2(i,:));
     data_vel = load (t_read3(i,:));
     
     D = [data_disp, data_force(:,2), data_vel(:,2)];
     eval(['data' num2str(i) ' = D;']);
 end
 
 %% Find the drag from every sett
 k1=0; k2=0; 
 for i = 1:length(parameters)
     
     if parameters(i,1) == 0
         k1 = 1+ k1;
        eval(['D'  ' = data' num2str(i) ';']);
        Drag_off(k1) = D(end,3);
     else
        eval(['D'  ' = data' num2str(i) ';']);
        k2= k2+1;
        Drag_on(k2) = D(end,3);
     end
 end
 
%% Find the difference from theory to USFOS
k1=0;
for i=1:length(parameters)
    if parameters(i,1) ~= 0
        k1 = 1+ k1;
        theory_vel(k1) = 100/parameters(i,3); 
        theory_drag(k1) = F_drag(theory_vel(k1));
    end
end

Exp_drag = Drag_off - Drag_on;

diff_drag = theory_drag-Exp_drag;

diff_drag2 = theory_drag./Exp_drag;

diff = [theory_vel; diff_drag];
correct = [theory_vel; diff_drag2];

%% Plot the differences
figure 
plot(theory_vel(:),diff_drag(:))

figure
plot(theory_vel(:),diff_drag2(:))

%% Save the plots
fileID = fopen('./postpro/diff_drag.plo','w');
fprintf(fileID,'%f %f\r\n',diff);
fclose(fileID);

fileID = fopen('./postpro/correction_fac_drag.plo','w');
fprintf(fileID,'%f %f\r\n',correct);
fclose(fileID);
